@@ -91,7 +91,7 @@ class ReadPasswordJobPrivate : public JobPrivate {
     Q_OBJECT
 public:
     explicit ReadPasswordJobPrivate( const QString &service_, ReadPasswordJob* qq );
-    void scheduledStart();
+    void scheduledStart() override;
 
 #if defined(KEYCHAIN_DBUS)
     void fallbackOnError(const QDBusError& err);
@@ -114,7 +114,7 @@ class WritePasswordJobPrivate : public JobPrivate {
     Q_OBJECT
 public:
     explicit WritePasswordJobPrivate( const QString &service_, WritePasswordJob* qq );
-    void scheduledStart();
+    void scheduledStart() override;
 
 #if defined(KEYCHAIN_DBUS)
     void fallbackOnError(const QDBusError& err);
@@ -128,7 +128,7 @@ class DeletePasswordJobPrivate : public JobPrivate {
 public:
     explicit DeletePasswordJobPrivate( const QString &service_, DeletePasswordJob* qq );
 
-    void scheduledStart();
+    void scheduledStart() override;
 
 #if defined(KEYCHAIN_DBUS)
     void fallbackOnError(const QDBusError& err);
